;; Generated package description from python.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "python" "0.30.0.20260724.47" "Python's flying circus support for Emacs" '((emacs "29.1") (compat "29.1.1.0")) :commit "cc5491c575d47eb14c7206598c515b9aed4a5724" :authors '(("Fabián E. Gallina" . "fgallina@gnu.org")) :maintainer '(nil . "emacs-devel@gnu.org") :keywords '("languages") :url "https://github.com/fgallina/python.el")
